OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Üksikasjad",
    "Rename" : "Nimeta ümber",
    "Move" : "Liiguta",
    "Delete" : "Kustuta",
    "Delete selection" : "Kustuta valik",
    "Select all" : "Vali kõik",
    "New" : "Uus",
    "New folder" : "Uus kaust",
    "Cancel" : "Loobu",
    "Recent" : "Hiljutised",
    "Import" : "Impordi",
    "Export" : "Ekspordi",
    "Clear data" : "Tühjenda andmed",
    "Title" : "Pealkiri",
    "Link" : "Link",
    "Tags" : "Sildid",
    "Notes" : "Märkmed",
    "Owner" : "Omanik",
    "Sharing" : "Jagamine",
    "Share link" : "Jaga link",
    "Copy link" : "Kopeeri link",
    "Allow editing" : "Luba muutmine",
    "Link copied" : "Link kopeeritud",
    "Privacy" : "Privaatsus",
    "Folder" : "Kaust",
    "Save" : "Salvesta",
    "Failed to delete bookmark" : "Järjehoidja kustutamine ebaõnnestus",
    "Failed to delete folder" : "Kausta kustutamine ebaõnnestus"
},
"nplurals=2; plural=(n != 1);");
